aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorgpcf <gabriel@gpcf.eu>2017-06-08 01:45:41 +0200
committerBeha <shacknetisp@mail.com>2017-06-07 19:45:41 -0400
commit83093a4160c38a6d0618bf44d3eca55ad3046b41 (patch)
treef65c27cc34bbcb1cba28888460cb8ff281d69442
parentf777f0b5253b41d023af0c3c6cbd37d3483484c9 (diff)
downloadelevator-83093a4160c38a6d0618bf44d3eca55ad3046b41.tar.gz
elevator-83093a4160c38a6d0618bf44d3eca55ad3046b41.tar.bz2
elevator-83093a4160c38a6d0618bf44d3eca55ad3046b41.zip
Added recipe that uses hemp rope instead of chains (#2)
-rw-r--r--depends.txt1
-rw-r--r--init.lua31
2 files changed, 30 insertions, 2 deletions
diff --git a/depends.txt b/depends.txt
index 175eea5..6796bf4 100644
--- a/depends.txt
+++ b/depends.txt
@@ -2,3 +2,4 @@ default
technic?
homedecor?
chains?
+farming?
diff --git a/init.lua b/init.lua
index f8b4320..a0a9e26 100644
--- a/init.lua
+++ b/init.lua
@@ -877,6 +877,33 @@ if technic_path and chains_path then
{"chains:chain", "default:diamond", "chains:chain"}
},
})
-else
- -- Recipes without technic & chains required.
+elseif technic_path and farming and farming.mod and farming.mod == "redo" then
+ -- add alternative recipe with hemp rope
+ minetest.register_craft({
+ output = "elevator:elevator",
+ recipe = {
+ {"technic:cast_iron_ingot", "farming:hemp_rope", "technic:cast_iron_ingot"},
+ {"technic:cast_iron_ingot", "default:mese_crystal", "technic:cast_iron_ingot"},
+ {"technic:stainless_steel_ingot", "default:glass", "technic:stainless_steel_ingot"},
+ },
+ })
+
+ minetest.register_craft({
+ output = "elevator:shaft",
+ recipe = {
+ {"technic:cast_iron_ingot", "default:glass"},
+ {"default:glass", "farming:hemp_rope"},
+ },
+ })
+
+ minetest.register_craft({
+ output = "elevator:motor",
+ recipe = {
+ {"default:diamond", "technic:control_logic_unit", "default:diamond"},
+ {"default:steelblock", "technic:motor", "default:steelblock"},
+ {"farming:hemp_rope", "default:diamond", "farming:hemp_rope"}
+ },
+ })
+
+ -- Recipes without technic & chains required.
end